==> zio-aws-ec2_2.13-5.17.104.13-sources.jar: zio/aws/ec2/model/ClientVpnAuthorizationRuleStatus.scala <==
package zio.aws.ec2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class ClientVpnAuthorizationRuleStatus(
    code: Option[zio.aws.ec2.model.ClientVpnAuthorizationRuleStatusCode] = None,
    message: Option[String] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.ClientVpnAuthorizationRuleStatus = {
    import ClientVpnAuthorizationRuleStatus.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.ClientVpnAuthorizationRuleStatus
      .builder()
      .optionallyWith(code.map(value => value.unwrap))(_.code)
      .optionallyWith(message.map(value => value: java.lang.String))(_.message)
      .build()
  }
  def asReadOnly: zio.aws.ec2.model.ClientVpnAuthorizationRuleStatus.ReadOnly =
    zio.aws.ec2.model.ClientVpnAuthorizationRuleStatus.wrap(buildAwsValue())
}
object ClientVpnAuthorizationRuleStatus {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.ClientVpnAuthorizationRuleStatus
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.ClientVpnAuthorizationRuleStatus =
      zio.aws.ec2.model.ClientVpnAuthorizationRuleStatus(
        code.map(value => value),
        message.map(value => value)
      )
    def code: Option[zio.aws.ec2.model.ClientVpnAuthorizationRuleStatusCode]
    def message: Option[String]
    def getCode: ZIO[
      Any,
      AwsError,
      zio.aws.ec2.model.ClientVpnAuthorizationRuleStatusCode
    ] = AwsError.unwrapOptionField("code", code)
    def getMessage: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("message", message)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.ClientVpnAuthorizationRuleStatus
  ) extends zio.aws.ec2.model.ClientVpnAuthorizationRuleStatus.ReadOnly {
    override val code
        : Option[zio.aws.ec2.model.ClientVpnAuthorizationRuleStatusCode] = scala
      .Option(impl.code())
      .map(value =>
        zio.aws.ec2.model.ClientVpnAuthorizationRuleStatusCode.wrap(value)
      )
    override val message: Option[String] =
      scala.Option(impl.message()).map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.ClientVpnAuthorizationRuleStatus
  ): zio.aws.ec2.model.ClientVpnAuthorizationRuleStatus.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-ec2_2.13-5.17.209.1-sources.jar: zio/aws/ec2/model/ClientVpnAuthorizationRuleStatus.scala <==
package zio.aws.ec2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class ClientVpnAuthorizationRuleStatus(
    code: Optional[zio.aws.ec2.model.ClientVpnAuthorizationRuleStatusCode] =
      Optional.Absent,
    message: Optional[String] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.ClientVpnAuthorizationRuleStatus = {
    import ClientVpnAuthorizationRuleStatus.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.ClientVpnAuthorizationRuleStatus
      .builder()
      .optionallyWith(code.map(value => value.unwrap))(_.code)
      .optionallyWith(message.map(value => value: java.lang.String))(_.message)
      .build()
  }
  def asReadOnly: zio.aws.ec2.model.ClientVpnAuthorizationRuleStatus.ReadOnly =
    zio.aws.ec2.model.ClientVpnAuthorizationRuleStatus.wrap(buildAwsValue())
}
object ClientVpnAuthorizationRuleStatus {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.ClientVpnAuthorizationRuleStatus
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.ClientVpnAuthorizationRuleStatus =
      zio.aws.ec2.model.ClientVpnAuthorizationRuleStatus(
        code.map(value => value),
        message.map(value => value)
      )
    def code: Optional[zio.aws.ec2.model.ClientVpnAuthorizationRuleStatusCode]
    def message: Optional[String]
    def getCode: ZIO[
      Any,
      AwsError,
      zio.aws.ec2.model.ClientVpnAuthorizationRuleStatusCode
    ] = AwsError.unwrapOptionField("code", code)
    def getMessage: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("message", message)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.ClientVpnAuthorizationRuleStatus
  ) extends zio.aws.ec2.model.ClientVpnAuthorizationRuleStatus.ReadOnly {
    override val code
        : Optional[zio.aws.ec2.model.ClientVpnAuthorizationRuleStatusCode] =
      zio.aws.core.internal
        .optionalFromNullable(impl.code())
        .map(value =>
          zio.aws.ec2.model.ClientVpnAuthorizationRuleStatusCode.wrap(value)
        )
    override val message: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.message())
      .map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.ClientVpnAuthorizationRuleStatus
  ): zio.aws.ec2.model.ClientVpnAuthorizationRuleStatus.ReadOnly = new Wrapper(
    impl
  )
}
